The base NITF header object (sarpy.io.general.nitf_elements.base)
=================================================================

.. automodule:: sarpy.io.general.nitf_elements.base
    :members:
    :show-inheritance:
    :inherited-members:
